@@ -90,7 +90,7 @@
  * </example>
  *
  * Since: 0.7.0
- **/
+ */
 
 #include <config.h>
 #include <glib.h>
@@ -147,7 +147,7 @@ gdata_batch_operation_class_init (GDataBatchOperationClass *klass)
 	 * The service this batch operation is attached to.
 	 *
 	 * Since: 0.7.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_SERVICE,
 	                                 g_param_spec_object ("service",
 	                                                      "Service", "The service this batch operation is attached to.",
@@ -177,7 +177,7 @@ gdata_batch_operation_class_init (GDataBatchOperationClass *klass)
 	 * The feed URI that this batch operation will be sent to.
 	 *
 	 * Since: 0.7.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_FEED_URI,
 	                                 g_param_spec_string ("feed-uri",
 	                                                      "Feed URI", "The feed URI that this batch operation will be sent to.",
@@ -276,7 +276,7 @@ gdata_batch_operation_finalize (GObject *object)
  * Return value: (transfer none): the batch operation's attached service
  *
  * Since: 0.7.0
- **/
+ */
 GDataService *
 gdata_batch_operation_get_service (GDataBatchOperation *self)
 {
@@ -311,7 +311,7 @@ gdata_batch_operation_get_authorization_domain (GDataBatchOperation *self)
  * Return value: the batch operation's feed URI
  *
  * Since: 0.7.0
- **/
+ */
 const gchar *
 gdata_batch_operation_get_feed_uri (GDataBatchOperation *self)
 {
@@ -349,7 +349,7 @@ add_operation (GDataBatchOperation *self, GDataBatchOperationType type, GDataEnt
  * Return value: the relevant #BatchOperation, or %NULL
  *
  * Since: 0.7.0
- **/
+ */
 BatchOperation *
 _gdata_batch_operation_get_operation (GDataBatchOperation *self, guint id)
 {
@@ -388,7 +388,7 @@ run_callback_cb (BatchOperation *op)
  * #GDataBatchOperation was run with gdata_batch_operation_run() or gdata_batch_operation_run_async().
  *
  * Since: 0.7.0
- **/
+ */
 void
 _gdata_batch_operation_run_callback (GDataBatchOperation *self, BatchOperation *op, GDataEntry *entry, GError *error)
 {
@@ -458,7 +458,7 @@ operation_free (BatchOperation *op)
  * Return value: operation ID for the added query, or <code class="literal">0</code>
  *
  * Since: 0.7.0
- **/
+ */
 guint
 gdata_batch_operation_add_query (GDataBatchOperation *self, const gchar *id, GType entry_type,
                                  GDataBatchOperationCallback callback, gpointer user_data)
@@ -501,7 +501,7 @@ gdata_batch_operation_add_query (GDataBatchOperation *self, const gchar *id, GTy
  * Return value: operation ID for the added insertion, or <code class="literal">0</code>
  *
  * Since: 0.7.0
- **/
+ */
 guint
 gdata_batch_operation_add_insertion (GDataBatchOperation *self, GDataEntry *entry, GDataBatchOperationCallback callback, gpointer user_data)
 {
@@ -531,7 +531,7 @@ gdata_batch_operation_add_insertion (GDataBatchOperation *self, GDataEntry *entr
  * Return value: operation ID for the added update, or <code class="literal">0</code>
  *
  * Since: 0.7.0
- **/
+ */
 guint
 gdata_batch_operation_add_update (GDataBatchOperation *self, GDataEntry *entry, GDataBatchOperationCallback callback, gpointer user_data)
 {
@@ -561,7 +561,7 @@ gdata_batch_operation_add_update (GDataBatchOperation *self, GDataEntry *entry,
  * Return value: operation ID for the added deletion, or <code class="literal">0</code>
  *
  * Since: 0.7.0
- **/
+ */
 guint
 gdata_batch_operation_add_deletion (GDataBatchOperation *self, GDataEntry *entry, GDataBatchOperationCallback callback, gpointer user_data)
 {
@@ -594,7 +594,7 @@ gdata_batch_operation_add_deletion (GDataBatchOperation *self, GDataEntry *entry
  * Return value: %TRUE on success, %FALSE otherwise
  *
  * Since: 0.7.0
- **/
+ */
 gboolean
 gdata_batch_operation_run (GDataBatchOperation *self, GCancellable *cancellable, GError **error)
 {
@@ -724,20 +724,16 @@ error:
 }
 
 static void
-run_thread (GSimpleAsyncResult *result, GDataBatchOperation *operation, GCancellable *cancellable)
+run_thread (GTask *task, gpointer source_object, gpointer task_data, GCancellable *cancellable)
 {
-	gboolean success;
-	GError *error = NULL;
+	GDataBatchOperation *operation = GDATA_BATCH_OPERATION (source_object);
+	g_autoptr(GError) error = NULL;
 
 	/* Run the batch operation and return */
-	success = gdata_batch_operation_run (operation, cancellable, &error);
-	g_simple_async_result_set_op_res_gboolean (result, success);
-
-	/* Propagate any errors */
-	if (success == FALSE) {
-		g_simple_async_result_set_from_error (result, error);
-		g_error_free (error);
-	}
+	if (!gdata_batch_operation_run (operation, cancellable, &error))
+		g_task_return_error (task, g_steal_pointer (&error));
+	else
+		g_task_return_boolean (task, TRUE);
 }
 
 /**
@@ -757,11 +753,11 @@ run_thread (GSimpleAsyncResult *result, GDataBatchOperation *operation, GCancell
  * the batch operation.
  *
  * Since: 0.7.0
- **/
+ */
 void
 gdata_batch_operation_run_async (GDataBatchOperation *self, GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-	GSimpleAsyncResult *result;
+	g_autoptr(GTask) task = NULL;
 
 	g_return_if_fail (GDATA_IS_BATCH_OPERATION (self));
 	g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
@@ -770,14 +766,9 @@ gdata_batch_operation_run_async (GDataBatchOperation *self, GCancellable *cancel
 	/* Mark the operation as async for the purposes of deciding where to call the callbacks */
 	self->priv->is_async = TRUE;
 
-	result = g_simple_async_result_new (G_OBJECT (self), callback, user_data, gdata_batch_operation_run_async);
-
-	/* Disable handling of cancellation so that g_simple_async_result_run_in_thread() doesn't return immediately without calling run_thread() if
-	 * cancellable has already been cancelled by this point. */
-	g_simple_async_result_set_handle_cancellation (result, FALSE);
-
-	g_simple_async_result_run_in_thread (result, (GSimpleAsyncThreadFunc) run_thread, G_PRIORITY_DEFAULT, cancellable);
-	g_object_unref (result);
+	task = g_task_new (self, cancellable, callback, user_data);
+	g_task_set_source_tag (task, gdata_batch_operation_run_async);
+	g_task_run_in_thread (task, run_thread);
 }
 
 /**
@@ -793,21 +784,20 @@ gdata_batch_operation_run_async (GDataBatchOperation *self, GCancellable *cancel
  * Return value: %TRUE on success, %FALSE otherwise
  *
  * Since: 0.7.0
- **/
+ */
 gboolean
 gdata_batch_operation_run_finish (GDataBatchOperation *self, GAsyncResult *async_result, GError **error)
 {
 	GDataBatchOperationPrivate *priv = self->priv;
-	GError *child_error = NULL;
-	GSimpleAsyncResult *result = G_SIMPLE_ASYNC_RESULT (async_result);
+	g_autoptr(GError) child_error = NULL;
 
 	g_return_val_if_fail (GDATA_IS_BATCH_OPERATION (self), FALSE);
 	g_return_val_if_fail (G_IS_ASYNC_RESULT (async_result), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+	g_return_val_if_fail (g_task_is_valid (async_result, self), FALSE);
+	g_return_val_if_fail (g_async_result_is_tagged (async_result, gdata_batch_operation_run_async), FALSE);
 
-	g_warn_if_fail (g_simple_async_result_get_source_tag (result) == gdata_batch_operation_run_async);
-
-	if (g_simple_async_result_propagate_error (result, &child_error) == TRUE) {
+	if (!g_task_propagate_boolean (G_TASK (async_result), &child_error)) {
 		if (priv->has_run == FALSE) {
 			GHashTableIter iter;
 			gpointer op_id;
@@ -826,10 +816,10 @@ gdata_batch_operation_run_finish (GDataBatchOperation *self, GAsyncResult *async
 			priv->is_async = TRUE;
 		}
 
-		g_propagate_error (error, child_error);
+		g_propagate_error (error, g_steal_pointer (&child_error));
 
 		return FALSE;
 	}
 
-	return g_simple_async_result_get_op_res_gboolean (result);
+	return TRUE;
 }
