@@ -787,11 +787,14 @@ gdata_entry_get_id (GDataEntry *self)
 	/* We have to get the actual property since GDataDocumentsEntry overrides it. We then store it in our own ID field so that we can
 	 * free it later on. */
 	g_object_get (G_OBJECT (self), "id", &id, NULL);
+	if (g_strcmp0 (id, self->priv->id) != 0) {
+		g_free (self->priv->id);
+		self->priv->id = id;
+	} else {
+		g_free (id);
+	}
 
-	g_free (self->priv->id);
-	self->priv->id = id;
-
-	return id;
+	return self->priv->id;
 }
 
 /**
@@ -975,9 +978,9 @@ gdata_entry_add_category (GDataEntry *self, GDataCategory *category)
  * gdata_entry_get_categories:
  * @self: a #GDataEntry
  *
- * Gets a list of the #GDataCategory<!-- -->s containing this entry.
+ * Gets a list of the #GDataCategorys containing this entry.
  *
- * Return value: (element-type GData.Category) (transfer none): a #GList of #GDataCategory<!-- -->s
+ * Return value: (element-type GData.Category) (transfer none): a #GList of #GDataCategorys
  *
  * Since: 0.2.0
  */
@@ -992,9 +995,9 @@ gdata_entry_get_categories (GDataEntry *self)
  * gdata_entry_get_authors:
  * @self: a #GDataEntry
  *
- * Gets a list of the #GDataAuthor<!-- -->s for this entry.
+ * Gets a list of the #GDataAuthors for this entry.
  *
- * Return value: (element-type GData.Author) (transfer none): a #GList of #GDataAuthor<!-- -->s
+ * Return value: (element-type GData.Author) (transfer none): a #GList of #GDataAuthors
  *
  * Since: 0.7.0
  */
@@ -1181,7 +1184,7 @@ gdata_entry_look_up_link (GDataEntry *self, const gchar *rel)
  *
  * If you will only use the first link found, consider calling gdata_entry_look_up_link() instead.
  *
- * Return value: (element-type GData.Link) (transfer container): a #GList of #GDataLink<!-- -->s, or %NULL if none were found; free the list with
+ * Return value: (element-type GData.Link) (transfer container): a #GList of #GDataLinks, or %NULL if none were found; free the list with
  * g_list_free()
  *
  * Since: 0.4.0
