@@ -40,7 +40,7 @@
  *
  * For more information on the standard GData query parameters supported by #GDataQuery, see the <ulink type="http"
  * url="http://code.google.com/apis/gdata/docs/2.0/reference.html#Queries">online documentation</ulink>.
- **/
+ */
 
 #include <glib.h>
 #include <string.h>
@@ -68,22 +68,37 @@ struct _GDataQueryPrivate {
 	gboolean is_strict;
 	guint max_results;
 
-	/* Pagination management. Supports three states:
-	 *  1.  (next_uri == NULL && !use_next_uri):
-	 *        Implement pagination by incrementing #GDataQuery:start-index
-	 *        internally with each call to gdata_query_next_page(). Stop
-	 *        when the returned #GDataFeed is empty.
-	 *  2a. (next_uri != NULL && use_next_uri):
-	 *        Implement pagination with an explicit URI for the next page,
-	 *        which will be used when gdata_query_next_page() is called.
-	 *  2b. (next_uri == NULL && use_next_uri):
-	 *        End of pagination using known URIs; return an empty
-	 *        #GDataFeed when gdata_query_next_page() is called.
+	/* Pagination management. The type of pagination is set as
+	 * pagination_type, and should be set in the init() vfunc implementation
+	 * of any class derived from GDataQuery. It defaults to
+	 * %GDATA_QUERY_PAGINATION_INDEXED, which most subclasses will not want.
+	 *
+	 * The next_uri, previous_uri or next_page_token are set by
+	 * #GDataService if a query returns a new #GDataFeed containing them. If
+	 * the user then calls next_page() or previous_page(), use_next_page or
+	 * use_previous_page are set as appropriate, and the next call to
+	 * get_uri() will return a URI for the next or previous page. This might
+	 * be next_uri, previous_uri, or a constructed URI which appends the
+	 * next_page_token.
+	 *
+	 * Note that %GDATA_QUERY_PAGINATION_TOKENS does not support returning
+	 * to the previous page.
+	 *
+	 * It is not invalid to have use_next_page set and to not have a
+	 * next_uri for %GDATA_QUERY_PAGINATION_URIS; or to not have a
+	 * next_page_token for %GDATA_QUERY_PAGINATION_TOKENS: this signifies
+	 * that the current set of results are the last page. There are no
+	 * further pages. Similarly for use_previous_page and a %NULL
+	 * previous_page.
 	 */
+	GDataQueryPaginationType pagination_type;
+
 	gchar *next_uri;
 	gchar *previous_uri;
-	gboolean use_next_uri;
-	gboolean use_previous_uri;
+	gchar *next_page_token;
+
+	gboolean use_next_page;
+	gboolean use_previous_page;
 
 	gchar *etag;
 };
@@ -135,7 +150,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	 *
 	 * Example: to search for all entries that contain the exact phrase "Elizabeth Bennet" and the word "Darcy" but don't contain the
 	 * word "Austen", use the following query: <userinput>"Elizabeth Bennet" Darcy -Austen</userinput>.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_Q,
 	                                 g_param_spec_string ("q",
 	                                                      "Query terms", "Query terms for which to search.",
@@ -165,7 +180,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	 * that has no scheme, use an empty pair of curly braces. If you don't specify curly braces, then categories in any scheme will match.
 	 *
 	 * The above features can be combined. For example: <userinput>A|-{urn:google.com}B/-C</userinput> means (A OR (NOT B)) AND (NOT C).
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_CATEGORIES,
 	                                 g_param_spec_string ("categories",
 	                                                      "Category string", "Category search string.",
@@ -176,7 +191,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	 * GDataQuery:author:
 	 *
 	 * An entry author. The service returns entries where the author name and/or e-mail address match your query string.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_AUTHOR,
 	                                 g_param_spec_string ("author",
 	                                                      "Author", "Author search string.",
@@ -187,7 +202,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	 * GDataQuery:updated-min:
 	 *
 	 * Lower bound on the entry update date, inclusive.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_UPDATED_MIN,
 	                                 g_param_spec_int64 ("updated-min",
 	                                                     "Minimum update date", "Minimum date for updates on returned entries.",
@@ -198,7 +213,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	 * GDataQuery:updated-max:
 	 *
 	 * Upper bound on the entry update date, exclusive.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_UPDATED_MAX,
 	                                 g_param_spec_int64 ("updated-max",
 	                                                     "Maximum update date", "Maximum date for updates on returned entries.",
@@ -209,7 +224,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	 * GDataQuery:published-min:
 	 *
 	 * Lower bound on the entry publish date, inclusive.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_PUBLISHED_MIN,
 	                                 g_param_spec_int64 ("published-min",
 	                                                     "Minimum publish date", "Minimum date for returned entries to be published.",
@@ -220,7 +235,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	 * GDataQuery:published-max:
 	 *
 	 * Upper bound on the entry publish date, exclusive.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_PUBLISHED_MAX,
 	                                 g_param_spec_int64 ("published-max",
 	                                                     "Maximum publish date", "Maximum date for returned entries to be published.",
@@ -234,7 +249,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	 * implement pagination, rather than manually changing #GDataQuery:start-index.
 	 *
 	 * Use <code class="literal">0</code> to not specify a start index.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_START_INDEX,
 	                                 g_param_spec_uint ("start-index",
 	                                                    "Start index", "One-based result start index.",
@@ -248,7 +263,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	 * not recognised.
 	 *
 	 * Since: 0.2.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_IS_STRICT,
 	                                 g_param_spec_boolean ("is-strict",
 	                                                       "Strict?", "Should the server be strict about the query?",
@@ -262,7 +277,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	 * to receive the entire feed, specify a large number such as %G_MAXUINT for this property.
 	 *
 	 * Use <code class="literal">0</code> to not specify a maximum number of results.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_MAX_RESULTS,
 	                                 g_param_spec_uint ("max-results",
 	                                                    "Maximum number of results", "The maximum number of entries to return.",
@@ -279,7 +294,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	 * query, it must be set again using gdata_query_set_etag() after setting any other properties.
 	 *
 	 * Since: 0.2.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_ETAG,
 	                                 g_param_spec_string ("etag",
 	                                                      "ETag", "An ETag against which to check.",
@@ -295,6 +310,8 @@ gdata_query_init (GDataQuery *self)
 	self->priv->updated_max = -1;
 	self->priv->published_min = -1;
 	self->priv->published_max = -1;
+
+	_gdata_query_set_pagination_type (self, GDATA_QUERY_PAGINATION_INDEXED);
 }
 
 static void
@@ -309,6 +326,7 @@ gdata_query_finalize (GObject *object)
 	g_free (priv->next_uri);
 	g_free (priv->previous_uri);
 	g_free (priv->etag);
+	g_free (priv->next_page_token);
 
 	/* Chain up to the parent class */
 	G_OBJECT_CLASS (gdata_query_parent_class)->finalize (object);
@@ -424,8 +442,11 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 		APPEND_SEP
 		g_string_append (query_uri, "q=");
 
-		if (priv->q != NULL)
+		if (priv->q != NULL) {
 			g_string_append_uri_escaped (query_uri, priv->q, NULL, FALSE);
+			if (priv->q_internal != NULL)
+				g_string_append (query_uri, "%20and%20");
+		}
 		if (priv->q_internal != NULL)
 			g_string_append_uri_escaped (query_uri, priv->q_internal, NULL, FALSE);
 	}
@@ -490,6 +511,13 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 		APPEND_SEP
 		g_string_append_printf (query_uri, "max-results=%u", priv->max_results);
 	}
+
+	if (priv->pagination_type == GDATA_QUERY_PAGINATION_TOKENS && priv->use_next_page &&
+	    priv->next_page_token != NULL && *priv->next_page_token != '\0') {
+		APPEND_SEP
+		g_string_append (query_uri, "pageToken=");
+		g_string_append_uri_escaped (query_uri, priv->next_page_token, NULL, FALSE);
+	}
 }
 
 /**
@@ -499,7 +527,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
  * Creates a new #GDataQuery with its #GDataQuery:q property set to @q.
  *
  * Return value: a new #GDataQuery
- **/
+ */
 GDataQuery *
 gdata_query_new (const gchar *q)
 {
@@ -516,7 +544,7 @@ gdata_query_new (const gchar *q)
  * applied.
  *
  * Return value: a new #GDataQuery
- **/
+ */
 GDataQuery *
 gdata_query_new_with_limits (const gchar *q, guint start_index, guint max_results)
 {
@@ -538,7 +566,7 @@ gdata_query_new_with_limits (const gchar *q, guint start_index, guint max_result
  * The query URI is what functions like gdata_service_query() use to query the online service.
  *
  * Return value: a query URI; free with g_free()
- **/
+ */
 gchar *
 gdata_query_get_query_uri (GDataQuery *self, const gchar *feed_uri)
 {
@@ -550,10 +578,12 @@ gdata_query_get_query_uri (GDataQuery *self, const gchar *feed_uri)
 	g_return_val_if_fail (feed_uri != NULL, NULL);
 
 	/* Check to see if we're paginating first */
-	if (self->priv->use_next_uri == TRUE)
-		return g_strdup (self->priv->next_uri);
-	if (self->priv->use_previous_uri == TRUE)
-		return g_strdup (self->priv->previous_uri);
+	if (self->priv->pagination_type == GDATA_QUERY_PAGINATION_URIS) {
+		if (self->priv->use_next_page)
+			return g_strdup (self->priv->next_uri);
+		if (self->priv->use_previous_page)
+			return g_strdup (self->priv->previous_uri);
+	}
 
 	klass = GDATA_QUERY_GET_CLASS (self);
 	g_assert (klass->get_query_uri != NULL);
@@ -613,7 +643,7 @@ _gdata_query_clear_q_internal (GDataQuery *self)
  * Gets the #GDataQuery:q property.
  *
  * Return value: the q property, or %NULL if it is unset
- **/
+ */
 const gchar *
 gdata_query_get_q (GDataQuery *self)
 {
@@ -629,7 +659,7 @@ gdata_query_get_q (GDataQuery *self)
  * Sets the #GDataQuery:q property of the #GDataQuery to the new query string, @q.
  *
  * Set @q to %NULL to unset the property in the query URI.
- **/
+ */
 void
 gdata_query_set_q (GDataQuery *self, const gchar *q)
 {
@@ -650,7 +680,7 @@ gdata_query_set_q (GDataQuery *self, const gchar *q)
  * Gets the #GDataQuery:categories property.
  *
  * Return value: the categories property, or %NULL if it is unset
- **/
+ */
 const gchar *
 gdata_query_get_categories (GDataQuery *self)
 {
@@ -666,7 +696,7 @@ gdata_query_get_categories (GDataQuery *self)
  * Sets the #GDataQuery:categories property of the #GDataQuery to the new category string, @categories.
  *
  * Set @categories to %NULL to unset the property in the query URI.
- **/
+ */
 void
 gdata_query_set_categories (GDataQuery *self, const gchar *categories)
 {
@@ -687,7 +717,7 @@ gdata_query_set_categories (GDataQuery *self, const gchar *categories)
  * Gets the #GDataQuery:author property.
  *
  * Return value: the author property, or %NULL if it is unset
- **/
+ */
 const gchar *
 gdata_query_get_author (GDataQuery *self)
 {
@@ -703,7 +733,7 @@ gdata_query_get_author (GDataQuery *self)
  * Sets the #GDataQuery:author property of the #GDataQuery to the new author string, @author.
  *
  * Set @author to %NULL to unset the property in the query URI.
- **/
+ */
 void
 gdata_query_set_author (GDataQuery *self, const gchar *author)
 {
@@ -724,7 +754,7 @@ gdata_query_set_author (GDataQuery *self, const gchar *author)
  * Gets the #GDataQuery:updated-min property. If the property is unset, <code class="literal">-1</code> will be returned.
  *
  * Return value: the updated-min property, or <code class="literal">-1</code>
- **/
+ */
 gint64
 gdata_query_get_updated_min (GDataQuery *self)
 {
@@ -740,7 +770,7 @@ gdata_query_get_updated_min (GDataQuery *self)
  * Sets the #GDataQuery:updated-min property of the #GDataQuery to the new minimum update time, @updated_min.
  *
  * Set @updated_min to <code class="literal">-1</code> to unset the property in the query URI.
- **/
+ */
 void
 gdata_query_set_updated_min (GDataQuery *self, gint64 updated_min)
 {
@@ -761,7 +791,7 @@ gdata_query_set_updated_min (GDataQuery *self, gint64 updated_min)
  * Gets the #GDataQuery:updated-max property. If the property is unset, <code class="literal">-1</code> will be returned.
  *
  * Return value: the updated-max property, or <code class="literal">-1</code>
- **/
+ */
 gint64
 gdata_query_get_updated_max (GDataQuery *self)
 {
@@ -777,7 +807,7 @@ gdata_query_get_updated_max (GDataQuery *self)
  * Sets the #GDataQuery:updated-max property of the #GDataQuery to the new maximum update time, @updated_max.
  *
  * Set @updated_max to <code class="literal">-1</code> to unset the property in the query URI.
- **/
+ */
 void
 gdata_query_set_updated_max (GDataQuery *self, gint64 updated_max)
 {
@@ -798,7 +828,7 @@ gdata_query_set_updated_max (GDataQuery *self, gint64 updated_max)
  * Gets the #GDataQuery:published-min property. If the property is unset, <code class="literal">-1</code> will be returned.
  *
  * Return value: the published-min property, or <code class="literal">-1</code>
- **/
+ */
 gint64
 gdata_query_get_published_min (GDataQuery *self)
 {
@@ -814,7 +844,7 @@ gdata_query_get_published_min (GDataQuery *self)
  * Sets the #GDataQuery:published-min property of the #GDataQuery to the new minimum publish time, @published_min.
  *
  * Set @published_min to <code class="literal">-1</code> to unset the property in the query URI.
- **/
+ */
 void
 gdata_query_set_published_min (GDataQuery *self, gint64 published_min)
 {
@@ -835,7 +865,7 @@ gdata_query_set_published_min (GDataQuery *self, gint64 published_min)
  * Gets the #GDataQuery:published-max property. If the property is unset, <code class="literal">-1</code> will be returned.
  *
  * Return value: the published-max property, or <code class="literal">-1</code>
- **/
+ */
 gint64
 gdata_query_get_published_max (GDataQuery *self)
 {
@@ -851,7 +881,7 @@ gdata_query_get_published_max (GDataQuery *self)
  * Sets the #GDataQuery:published-max property of the #GDataQuery to the new maximum publish time, @published_max.
  *
  * Set @published_max to <code class="literal">-1</code> to unset the property in the query URI.
- **/
+ */
 void
 gdata_query_set_published_max (GDataQuery *self, gint64 published_max)
 {
@@ -872,7 +902,7 @@ gdata_query_set_published_max (GDataQuery *self, gint64 published_max)
  * Gets the #GDataQuery:start-index property.
  *
  * Return value: the start index property, or <code class="literal">0</code> if it is unset
- **/
+ */
 guint
 gdata_query_get_start_index (GDataQuery *self)
 {
@@ -888,7 +918,7 @@ gdata_query_get_start_index (GDataQuery *self)
  * Sets the #GDataQuery:start-index property of the #GDataQuery to the new one-based start index, @start_index.
  *
  * Set @start_index to <code class="literal">0</code> to unset the property in the query URI.
- **/
+ */
 void
 gdata_query_set_start_index (GDataQuery *self, guint start_index)
 {
@@ -910,7 +940,7 @@ gdata_query_set_start_index (GDataQuery *self, guint start_index)
  * Return value: the strict property
  *
  * Since: 0.2.0
- **/
+ */
 gboolean
 gdata_query_is_strict (GDataQuery *self)
 {
@@ -926,7 +956,7 @@ gdata_query_is_strict (GDataQuery *self)
  * Sets the #GDataQuery:is-strict property of the #GDataQuery to the new strict value, @is_strict.
  *
  * Since: 0.2.0
- **/
+ */
 void
 gdata_query_set_is_strict (GDataQuery *self, gboolean is_strict)
 {
@@ -946,7 +976,7 @@ gdata_query_set_is_strict (GDataQuery *self, gboolean is_strict)
  * Gets the #GDataQuery:max-results property.
  *
  * Return value: the maximum results property, or <code class="literal">0</code> if it is unset
- **/
+ */
 guint
 gdata_query_get_max_results (GDataQuery *self)
 {
@@ -962,7 +992,7 @@ gdata_query_get_max_results (GDataQuery *self)
  * Sets the #GDataQuery:max-results property of the #GDataQuery to the new maximum results value, @max_results.
  *
  * Set @max_results to <code class="literal">0</code> to unset the property in the query URI.
- **/
+ */
 void
 gdata_query_set_max_results (GDataQuery *self, guint max_results)
 {
@@ -984,7 +1014,7 @@ gdata_query_set_max_results (GDataQuery *self, guint max_results)
  * Return value: the ETag property, or %NULL if it is unset
  *
  * Since: 0.2.0
- **/
+ */
 const gchar *
 gdata_query_get_etag (GDataQuery *self)
 {
@@ -1002,7 +1032,7 @@ gdata_query_get_etag (GDataQuery *self)
  * Set @etag to %NULL to not check against the server-side ETag.
  *
  * Since: 0.2.0
- **/
+ */
 void
 gdata_query_set_etag (GDataQuery *self, const gchar *etag)
 {
@@ -1014,24 +1044,60 @@ gdata_query_set_etag (GDataQuery *self, const gchar *etag)
 }
 
 void
-_gdata_query_set_next_uri (GDataQuery *self, const gchar *next_uri)
+_gdata_query_clear_pagination (GDataQuery *self)
 {
 	g_return_if_fail (GDATA_IS_QUERY (self));
-	g_free (self->priv->next_uri);
-	self->priv->next_uri = g_strdup (next_uri);
-	self->priv->use_next_uri = FALSE;
-	self->priv->use_previous_uri = FALSE;
+
+	switch (self->priv->pagination_type) {
+	case GDATA_QUERY_PAGINATION_INDEXED:
+		/* Nothing to do here: indexes can always be incremented. */
+		break;
+	case GDATA_QUERY_PAGINATION_URIS:
+		g_clear_pointer (&self->priv->next_uri, g_free);
+		g_clear_pointer (&self->priv->previous_uri, g_free);
+		break;
+	case GDATA_QUERY_PAGINATION_TOKENS:
+		g_clear_pointer (&self->priv->next_page_token, g_free);
+		break;
+	default:
+		g_assert_not_reached ();
+	}
+
+	self->priv->use_next_page = FALSE;
+	self->priv->use_previous_page = FALSE;
 }
 
 void
-_gdata_query_set_next_uri_end (GDataQuery *self)
+_gdata_query_set_pagination_type (GDataQuery               *self,
+                                  GDataQueryPaginationType  type)
+{
+	g_debug ("%s: Pagination type set to %u", G_STRFUNC, type);
+
+	_gdata_query_clear_pagination (self);
+	self->priv->pagination_type = type;
+}
+
+void
+_gdata_query_set_next_page_token (GDataQuery  *self,
+                                  const gchar *next_page_token)
 {
 	g_return_if_fail (GDATA_IS_QUERY (self));
+	g_return_if_fail (self->priv->pagination_type ==
+	                  GDATA_QUERY_PAGINATION_TOKENS);
+
+	g_free (self->priv->next_page_token);
+	self->priv->next_page_token = g_strdup (next_page_token);
+}
+
+void
+_gdata_query_set_next_uri (GDataQuery *self, const gchar *next_uri)
+{
+	g_return_if_fail (GDATA_IS_QUERY (self));
+	g_return_if_fail (self->priv->pagination_type ==
+	                  GDATA_QUERY_PAGINATION_URIS);
 
 	g_free (self->priv->next_uri);
-	self->priv->next_uri = NULL;
-	self->priv->use_next_uri = TRUE;
-	self->priv->use_previous_uri = FALSE;
+	self->priv->next_uri = g_strdup (next_uri);
 }
 
 gboolean
@@ -1039,28 +1105,27 @@ _gdata_query_is_finished (GDataQuery *self)
 {
 	g_return_val_if_fail (GDATA_IS_QUERY (self), FALSE);
 
-	return (self->priv->next_uri == NULL && self->priv->use_next_uri);
+	switch (self->priv->pagination_type) {
+	case GDATA_QUERY_PAGINATION_INDEXED:
+		return FALSE;
+	case GDATA_QUERY_PAGINATION_URIS:
+		return (self->priv->next_uri == NULL && self->priv->use_next_page);
+	case GDATA_QUERY_PAGINATION_TOKENS:
+		return (self->priv->next_page_token == NULL && self->priv->use_next_page);
+	default:
+		g_assert_not_reached ();
+	}
 }
 
 void
 _gdata_query_set_previous_uri (GDataQuery *self, const gchar *previous_uri)
 {
 	g_return_if_fail (GDATA_IS_QUERY (self));
+	g_return_if_fail (self->priv->pagination_type ==
+	                  GDATA_QUERY_PAGINATION_URIS);
+
 	g_free (self->priv->previous_uri);
 	self->priv->previous_uri = g_strdup (previous_uri);
-	self->priv->use_next_uri = FALSE;
-	self->priv->use_previous_uri = FALSE;
-}
-
-void
-_gdata_query_set_previous_uri_end (GDataQuery *self)
-{
-	g_return_if_fail (GDATA_IS_QUERY (self));
-
-	g_free (self->priv->previous_uri);
-	self->priv->previous_uri = NULL;
-	self->priv->use_next_uri = TRUE;
-	self->priv->use_previous_uri = FALSE;
 }
 
 /**
@@ -1074,7 +1139,7 @@ _gdata_query_set_previous_uri_end (GDataQuery *self)
  * gdata_query_next_page() will fall back to using #GDataQuery:start-index to emulate true pagination if this fails.
  *
  * You <emphasis>should not</emphasis> implement pagination manually using #GDataQuery:start-index.
- **/
+ */
 void
 gdata_query_next_page (GDataQuery *self)
 {
@@ -1082,13 +1147,19 @@ gdata_query_next_page (GDataQuery *self)
 
 	g_return_if_fail (GDATA_IS_QUERY (self));
 
-	if (priv->next_uri != NULL) {
-		priv->use_next_uri = TRUE;
-		priv->use_previous_uri = FALSE;
-	} else {
+	switch (self->priv->pagination_type) {
+	case GDATA_QUERY_PAGINATION_INDEXED:
 		if (priv->start_index == 0)
 			priv->start_index++;
 		priv->start_index += priv->max_results;
+		break;
+	case GDATA_QUERY_PAGINATION_URIS:
+	case GDATA_QUERY_PAGINATION_TOKENS:
+		priv->use_next_page = TRUE;
+		priv->use_previous_page = FALSE;
+		break;
+	default:
+		g_assert_not_reached ();
 	}
 
 	/* Our current ETag will no longer be relevant */
@@ -1105,28 +1176,47 @@ gdata_query_next_page (GDataQuery *self)
  * See the documentation for gdata_query_next_page() for an explanation of how query URIs from the feeds are used to this end.
  *
  * Return value: %TRUE if there is a previous page and it has been switched to, %FALSE otherwise
- **/
+ */
 gboolean
 gdata_query_previous_page (GDataQuery *self)
 {
 	GDataQueryPrivate *priv = self->priv;
+	gboolean retval;
 
 	g_return_val_if_fail (GDATA_IS_QUERY (self), FALSE);
 
-	if (priv->previous_uri != NULL) {
-		priv->use_previous_uri = TRUE;
-		priv->use_next_uri = FALSE;
-	} else if (priv->start_index <= priv->max_results ||
-	           (priv->previous_uri == NULL && priv->use_previous_uri)) {
-		return FALSE;
-	} else {
-		priv->start_index -= priv->max_results;
-		if (priv->start_index == 1)
-			priv->start_index--;
+	switch (self->priv->pagination_type) {
+	case GDATA_QUERY_PAGINATION_INDEXED:
+		if (priv->start_index <= priv->max_results) {
+			retval = FALSE;
+		} else {
+			priv->start_index -= priv->max_results;
+			if (priv->start_index == 1)
+				priv->start_index--;
+			retval = TRUE;
+		}
+		break;
+	case GDATA_QUERY_PAGINATION_URIS:
+		if (priv->previous_uri != NULL) {
+			priv->use_next_page = FALSE;
+			priv->use_previous_page = TRUE;
+			retval = TRUE;
+		} else {
+			retval = FALSE;
+		}
+		break;
+	case GDATA_QUERY_PAGINATION_TOKENS:
+		/* There are no previous page tokens, unfortunately. */
+		retval = FALSE;
+		break;
+	default:
+		g_assert_not_reached ();
 	}
 
-	/* Our current ETag will no longer be relevant */
-	gdata_query_set_etag (self, NULL);
+	if (retval) {
+		/* Our current ETag will no longer be relevant */
+		gdata_query_set_etag (self, NULL);
+	}
 
-	return TRUE;
+	return retval;
 }
