@@ -132,7 +132,7 @@
  * Before version 0.17.2, the Calendar service could be manipulated using
  * batch operations. That is no longer supported, and any batch operations
  * created on the calendar will fail.
- **/
+ */
 
 #include <config.h>
 #include <glib.h>
@@ -445,7 +445,7 @@ gdata_calendar_service_get_primary_authorization_domain (void)
  * For more details, see gdata_service_query().
  *
  * Return value: (transfer full): a #GDataFeed of query results; unref with g_object_unref()
- **/
+ */
 GDataFeed *
 gdata_calendar_service_query_all_calendars (GDataCalendarService *self, GDataQuery *query, GCancellable *cancellable,
                                             GDataQueryProgressCallback progress_callback, gpointer progress_user_data, GError **error)
@@ -494,7 +494,7 @@ gdata_calendar_service_query_all_calendars (GDataCalendarService *self, GDataQue
  * this function, and gdata_service_query_async(), which is the base asynchronous query function.
  *
  * Since: 0.9.1
- **/
+ */
 void
 gdata_calendar_service_query_all_calendars_async (GDataCalendarService *self, GDataQuery *query, GCancellable *cancellable,
                                                   GDataQueryProgressCallback progress_callback, gpointer progress_user_data,
@@ -511,11 +511,12 @@ gdata_calendar_service_query_all_calendars_async (GDataCalendarService *self, GD
 	/* Ensure we're authenticated first */
 	if (gdata_authorizer_is_authorized_for_domain (gdata_service_get_authorizer (GDATA_SERVICE (self)),
 	                                               get_calendar_authorization_domain ()) == FALSE) {
-		GSimpleAsyncResult *result = g_simple_async_result_new (G_OBJECT (self), callback, user_data, gdata_service_query_async);
-		g_simple_async_result_set_error (result, GDATA_SERVICE_ERROR, GDATA_SERVICE_ERROR_AUTHENTICATION_REQUIRED, "%s",
-		                                 _("You must be authenticated to query all calendars."));
-		g_simple_async_result_complete_in_idle (result);
-		g_object_unref (result);
+		g_autoptr(GTask) task = NULL;
+
+		task = g_task_new (self, cancellable, callback, user_data);
+		g_task_set_source_tag (task, gdata_service_query_async);
+		g_task_return_new_error (task, GDATA_SERVICE_ERROR, GDATA_SERVICE_ERROR_AUTHENTICATION_REQUIRED, "%s",
+		                         _("You must be authenticated to query all calendars."));
 
 		return;
 	}
@@ -542,7 +543,7 @@ gdata_calendar_service_query_all_calendars_async (GDataCalendarService *self, GD
  * For more details, see gdata_service_query().
  *
  * Return value: (transfer full): a #GDataFeed of query results; unref with g_object_unref()
- **/
+ */
 GDataFeed *
 gdata_calendar_service_query_own_calendars (GDataCalendarService *self, GDataQuery *query, GCancellable *cancellable,
                                             GDataQueryProgressCallback progress_callback, gpointer progress_user_data, GError **error)
@@ -591,7 +592,7 @@ gdata_calendar_service_query_own_calendars (GDataCalendarService *self, GDataQue
  * this function, and gdata_service_query_async(), which is the base asynchronous query function.
  *
  * Since: 0.9.1
- **/
+ */
 void
 gdata_calendar_service_query_own_calendars_async (GDataCalendarService *self, GDataQuery *query, GCancellable *cancellable,
                                                   GDataQueryProgressCallback progress_callback, gpointer progress_user_data,
@@ -608,11 +609,12 @@ gdata_calendar_service_query_own_calendars_async (GDataCalendarService *self, GD
 	/* Ensure we're authenticated first */
 	if (gdata_authorizer_is_authorized_for_domain (gdata_service_get_authorizer (GDATA_SERVICE (self)),
 	                                               get_calendar_authorization_domain ()) == FALSE) {
-		GSimpleAsyncResult *result = g_simple_async_result_new (G_OBJECT (self), callback, user_data, gdata_service_query_async);
-		g_simple_async_result_set_error (result, GDATA_SERVICE_ERROR, GDATA_SERVICE_ERROR_AUTHENTICATION_REQUIRED, "%s",
-		                                 _("You must be authenticated to query your own calendars."));
-		g_simple_async_result_complete_in_idle (result);
-		g_object_unref (result);
+		g_autoptr(GTask) task = NULL;
+
+		task = g_task_new (self, cancellable, callback, user_data);
+		g_task_set_source_tag (task, gdata_service_query_async);
+		g_task_return_new_error (task, GDATA_SERVICE_ERROR, GDATA_SERVICE_ERROR_AUTHENTICATION_REQUIRED, "%s",
+		                         _("You must be authenticated to query your own calendars."));
 
 		return;
 	}
@@ -654,7 +656,7 @@ build_events_uri (GDataCalendarCalendar *calendar)
  * For more details, see gdata_service_query().
  *
  * Return value: (transfer full): a #GDataFeed of query results; unref with g_object_unref()
- **/
+ */
 GDataFeed *
 gdata_calendar_service_query_events (GDataCalendarService *self, GDataCalendarCalendar *calendar, GDataQuery *query, GCancellable *cancellable,
                                      GDataQueryProgressCallback progress_callback, gpointer progress_user_data, GError **error)
@@ -711,7 +713,7 @@ gdata_calendar_service_query_events (GDataCalendarService *self, GDataCalendarCa
  * which is the base asynchronous query function.
  *
  * Since: 0.9.1
- **/
+ */
 void
 gdata_calendar_service_query_events_async (GDataCalendarService *self, GDataCalendarCalendar *calendar, GDataQuery *query, GCancellable *cancellable,
                                            GDataQueryProgressCallback progress_callback, gpointer progress_user_data,
@@ -729,11 +731,12 @@ gdata_calendar_service_query_events_async (GDataCalendarService *self, GDataCale
 	/* Ensure we're authenticated first */
 	if (gdata_authorizer_is_authorized_for_domain (gdata_service_get_authorizer (GDATA_SERVICE (self)),
 	                                               get_calendar_authorization_domain ()) == FALSE) {
-		GSimpleAsyncResult *result = g_simple_async_result_new (G_OBJECT (self), callback, user_data, gdata_service_query_async);
-		g_simple_async_result_set_error (result, GDATA_SERVICE_ERROR, GDATA_SERVICE_ERROR_AUTHENTICATION_REQUIRED, "%s",
-		                                 _("You must be authenticated to query your own calendars."));
-		g_simple_async_result_complete_in_idle (result);
-		g_object_unref (result);
+		g_autoptr(GTask) task = NULL;
+
+		task = g_task_new (self, cancellable, callback, user_data);
+		g_task_set_source_tag (task, gdata_service_query_async);
+		g_task_return_new_error (task, GDATA_SERVICE_ERROR, GDATA_SERVICE_ERROR_AUTHENTICATION_REQUIRED, "%s",
+		                         _("You must be authenticated to query your own calendars."));
 
 		return;
 	}
@@ -767,7 +770,7 @@ gdata_calendar_service_query_events_async (GDataCalendarService *self, GDataCale
  * Deprecated: 0.17.2: Use gdata_calendar_service_insert_calendar_event()
  *   instead to be able to specify the calendar to add the event to; otherwise
  *   the default calendar will be used.
- **/
+ */
 GDataCalendarEvent *
 gdata_calendar_service_insert_event (GDataCalendarService *self, GDataCalendarEvent *event, GCancellable *cancellable, GError **error)
 {
@@ -852,7 +855,7 @@ gdata_calendar_service_insert_calendar_event (GDataCalendarService *self,
  *   gdata_calendar_service_insert_calendar_event_async() instead to be able to
  *   specify the calendar to add the event to; otherwise the default calendar
  *   will be used.
- **/
+ */
 void
 gdata_calendar_service_insert_event_async (GDataCalendarService *self, GDataCalendarEvent *event, GCancellable *cancellable,
                                            GAsyncReadyCallback callback, gpointer user_data)
