@@ -27,6 +27,8 @@
 #include <gdata/gdata-upload-stream.h>
 #include <gdata/services/documents/gdata-documents-query.h>
 #include <gdata/services/documents/gdata-documents-feed.h>
+#include <gdata/services/documents/gdata-documents-metadata.h>
+#include <gdata/services/documents/gdata-documents-drive-query.h>
 
 G_BEGIN_DECLS
 
@@ -37,7 +39,7 @@ G_BEGIN_DECLS
  * Error codes for #GDataDocumentsService operations.
  *
  * Since: 0.4.0
- **/
+ */
 typedef enum {
 	GDATA_DOCUMENTS_SERVICE_ERROR_INVALID_CONTENT_TYPE
 } GDataDocumentsServiceError;
@@ -59,7 +61,7 @@ typedef struct _GDataDocumentsServicePrivate	GDataDocumentsServicePrivate;
  * All the fields in the #GDataDocumentsService structure are private and should never be accessed directly.
  *
  * Since: 0.4.0
- **/
+ */
 typedef struct {
 	GDataService parent;
 	GDataDocumentsServicePrivate *priv;
@@ -71,20 +73,38 @@ typedef struct {
  * All the fields in the #GDataDocumentsServiceClass structure are private and should never be accessed directly.
  *
  * Since: 0.4.0
- **/
+ */
 typedef struct {
 	/*< private >*/
 	GDataServiceClass parent;
+
+	/*< private >*/
+	/* Padding for future expansion */
+	void (*_g_reserved0) (void);
+	void (*_g_reserved1) (void);
+	void (*_g_reserved2) (void);
+	void (*_g_reserved3) (void);
+	void (*_g_reserved4) (void);
+	void (*_g_reserved5) (void);
 } GDataDocumentsServiceClass;
 
 GType gdata_documents_service_get_type (void) G_GNUC_CONST;
 GQuark gdata_documents_service_error_quark (void) G_GNUC_CONST;
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (GDataDocumentsService, g_object_unref)
+
 GDataDocumentsService *gdata_documents_service_new (GDataAuthorizer *authorizer) G_GNUC_WARN_UNUSED_RESULT G_GNUC_MALLOC;
 
 GDataAuthorizationDomain *gdata_documents_service_get_primary_authorization_domain (void) G_GNUC_CONST;
 GDataAuthorizationDomain *gdata_documents_service_get_spreadsheet_authorization_domain (void) G_GNUC_CONST;
 
+GDataDocumentsMetadata *gdata_documents_service_get_metadata (GDataDocumentsService *self, GCancellable *cancellable,
+                                                              GError **error)  G_GNUC_WARN_UNUSED_RESULT G_GNUC_MALLOC;
+void gdata_documents_service_get_metadata_async (GDataDocumentsService *self, GCancellable *cancellable,
+                                                 GAsyncReadyCallback callback, gpointer user_data);
+GDataDocumentsMetadata *gdata_documents_service_get_metadata_finish (GDataDocumentsService *self, GAsyncResult *async_result,
+                                                                     GError **error) G_GNUC_WARN_UNUSED_RESULT G_GNUC_MALLOC;
+
 GDataDocumentsFeed *gdata_documents_service_query_documents (GDataDocumentsService *self, GDataDocumentsQuery *query, GCancellable *cancellable,
                                                              GDataQueryProgressCallback progress_callback, gpointer progress_user_data,
                                                              GError **error) G_GNUC_WARN_UNUSED_RESULT G_GNUC_MALLOC;
@@ -93,6 +113,14 @@ void gdata_documents_service_query_documents_async (GDataDocumentsService *self,
                                                     GDestroyNotify destroy_progress_user_data,
                                                     GAsyncReadyCallback callback, gpointer user_data);
 
+GDataDocumentsFeed *gdata_documents_service_query_drives (GDataDocumentsService *self, GDataDocumentsDriveQuery *query, GCancellable *cancellable,
+                                                          GDataQueryProgressCallback progress_callback, gpointer progress_user_data,
+                                                          GError **error) G_GNUC_WARN_UNUSED_RESULT G_GNUC_MALLOC;
+void gdata_documents_service_query_drives_async (GDataDocumentsService *self, GDataDocumentsDriveQuery *query, GCancellable *cancellable,
+                                                 GDataQueryProgressCallback progress_callback, gpointer progress_user_data,
+                                                 GDestroyNotify destroy_progress_user_data,
+                                                 GAsyncReadyCallback callback, gpointer user_data);
+
 #include <gdata/services/documents/gdata-documents-document.h>
 #include <gdata/services/documents/gdata-documents-folder.h>
 #include <gdata/services/documents/gdata-documents-upload-query.h>
