@@ -30,10 +30,14 @@ G_BEGIN_DECLS
 /* HACK: Used to convert GDataLink:uri to ID and vice-versa. */
 #define GDATA_DOCUMENTS_URI_PREFIX "https://www.googleapis.com/drive/v2/files/"
 
+G_GNUC_INTERNAL void gdata_documents_utils_add_content_type (GDataDocumentsEntry *entry, const gchar *content_type);
+
 G_GNUC_INTERNAL GType gdata_documents_utils_get_type_from_content_type (const gchar *content_type);
 
 G_GNUC_INTERNAL const gchar *gdata_documents_utils_get_content_type (GDataDocumentsEntry *entry);
 
+G_GNUC_INTERNAL const gchar *gdata_documents_utils_get_id_from_link (GDataLink *_link);
+
 G_END_DECLS
 
 #endif /* !GDATA_DOCUMENTS_UTILS_H */
