@@ -99,7 +99,9 @@ gdata_tasks_task_class_init (GDataTasksTaskClass *klass)
 	/**
 	 * GDataTasksTask:parent:
 	 *
-	 * Parent task identifier. This field is omitted if it is a top-level task. This field is read-only.
+	 * Parent task identifier. This field is omitted if it is a top-level task.
+	 *
+	 * Since 0.17.10, this property is writable.
 	 *
 	 * Since: 0.15.0
 	 */
@@ -107,7 +109,7 @@ gdata_tasks_task_class_init (GDataTasksTaskClass *klass)
 	                                 g_param_spec_string ("parent",
 	                                 "Parent of task", "Identifier of parent task.",
 	                                 NULL,
-	                                 G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+	                                 G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GDataTasksTask:position:
@@ -115,7 +117,9 @@ gdata_tasks_task_class_init (GDataTasksTaskClass *klass)
 	 * String indicating the position of the task among its sibling tasks under the same parent task
 	 * or at the top level. If this string is greater than another task's corresponding position string
 	 * according to lexicographical ordering, the task is positioned after the other task under the same
-	 * parent task (or at the top level). This field is read-only.
+	 * parent task (or at the top level).
+	 *
+	 * Since 0.17.10, this property is writable.
 	 *
 	 * Since: 0.15.0
 	 */
@@ -123,7 +127,7 @@ gdata_tasks_task_class_init (GDataTasksTaskClass *klass)
 	                                 g_param_spec_string ("position",
 	                                 "Position of task", "Position of the task among sibling tasks using lexicographical order.",
 	                                 NULL,
-	                                 G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+	                                 G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GDataTasksTask:notes:
@@ -296,7 +300,11 @@ gdata_tasks_task_set_property (GObject *object, guint property_id, const GValue
 			gdata_tasks_task_set_is_deleted (self, g_value_get_boolean (value));
 			break;
 		case PROP_PARENT:
+			gdata_tasks_task_set_parent (self, g_value_get_string (value));
+			break;
 		case PROP_POSITION:
+			gdata_tasks_task_set_position (self, g_value_get_string (value));
+			break;
 		case PROP_HIDDEN:
 		/* Read-only */
 		default:
@@ -333,50 +341,11 @@ get_json (GDataParsable *parsable, JsonBuilder *builder)
 {
 	gchar *due;
 	gchar *completed;
-	GList *i;
-	GDataLink *_link;
-	GDataEntry *entry = GDATA_ENTRY (parsable);
+
 	GDataTasksTaskPrivate *priv = GDATA_TASKS_TASK (parsable)->priv;
 
-	/* Add all the general JSON. We can’t chain up to #GDataEntry here
-	 * because Google Tasks uses a different date format. */
-	json_builder_set_member_name (builder, "title");
-	json_builder_add_string_value (builder, gdata_entry_get_title (entry));
-
-	if (gdata_entry_get_id (entry)) {
-		json_builder_set_member_name (builder, "id");
-		json_builder_add_string_value (builder, gdata_entry_get_id (entry));
-	}
-
-	if (gdata_entry_get_updated (entry) != -1) {
-		gchar *updated = gdata_parser_int64_to_iso8601_numeric_timezone (gdata_entry_get_updated (entry));
-		json_builder_set_member_name (builder, "updated");
-		json_builder_add_string_value (builder, updated);
-		g_free (updated);
-	}
-
-	/* If we have a "kind" category, add that. */
-	for (i = gdata_entry_get_categories (entry); i != NULL; i = i->next) {
-		GDataCategory *category = GDATA_CATEGORY (i->data);
-
-		if (g_strcmp0 (gdata_category_get_scheme (category), "http://schemas.google.com/g/2005#kind") == 0) {
-			json_builder_set_member_name (builder, "kind");
-			json_builder_add_string_value (builder, gdata_category_get_term (category));
-		}
-	}
-
-	/* Add the ETag, if available. */
-	if (gdata_entry_get_etag (entry) != NULL) {
-		json_builder_set_member_name (builder, "etag");
-		json_builder_add_string_value (builder, gdata_entry_get_etag (entry));
-	}
-
-	/* Add the self-link. */
-	_link = gdata_entry_look_up_link (GDATA_ENTRY (parsable), GDATA_LINK_SELF);
-	if (_link != NULL) {
-		json_builder_set_member_name (builder, "selfLink");
-		json_builder_add_string_value (builder, gdata_link_get_uri (_link));
-	}
+	/* Chain up to the parent class */
+	GDATA_PARSABLE_CLASS (gdata_tasks_task_parent_class)->get_json (parsable, builder);
 
 	/* Add all the task specific JSON */
 
@@ -397,13 +366,13 @@ get_json (GDataParsable *parsable, JsonBuilder *builder)
 		json_builder_add_string_value (builder, priv->status);
 	}
 	if (priv->due != -1) {
-		due = gdata_parser_int64_to_iso8601_numeric_timezone (priv->due);
+		due = gdata_parser_int64_to_iso8601 (priv->due);
 		json_builder_set_member_name (builder, "due");
 		json_builder_add_string_value (builder, due);
 		g_free (due);
 	}
 	if (priv->completed != -1) {
-		completed = gdata_parser_int64_to_iso8601_numeric_timezone (priv->completed);
+		completed = gdata_parser_int64_to_iso8601 (priv->completed);
 		json_builder_set_member_name (builder, "completed");
 		json_builder_add_string_value (builder, completed);
 		g_free (completed);
@@ -455,6 +424,30 @@ gdata_tasks_task_get_parent (GDataTasksTask *self)
 	return self->priv->parent;
 }
 
+/**
+ * gdata_tasks_task_set_parent:
+ * @self: a #GDataTasksTask
+ * @parent: (nullable): parent of the task
+ *
+ * Sets the #GDataTasksTask:parent property.
+ *
+ * Since: 0.17.10
+ */
+void
+gdata_tasks_task_set_parent (GDataTasksTask *self, const gchar *parent)
+{
+	gchar *local_parent;
+	g_return_if_fail (GDATA_IS_TASKS_TASK (self));
+
+	if (g_strcmp0 (self->priv->parent, parent) == 0)
+		return;
+
+	local_parent = self->priv->parent;
+	self->priv->parent = g_strdup (parent);
+	g_free (local_parent);
+	g_object_notify (G_OBJECT (self), "parent");
+}
+
 /**
  * gdata_tasks_task_get_position:
  * @self: a #GDataTasksTask
@@ -472,6 +465,30 @@ gdata_tasks_task_get_position (GDataTasksTask *self)
 	return self->priv->position;
 }
 
+/**
+ * gdata_tasks_task_set_position:
+ * @self: a #GDataTasksTask
+ * @position: position of the task in the list
+ *
+ * Sets the #GDataTasksTask:position property.
+ *
+ * Since: 0.17.10
+ */
+void
+gdata_tasks_task_set_position (GDataTasksTask *self, const gchar *position)
+{
+	gchar *local_position;
+	g_return_if_fail (GDATA_IS_TASKS_TASK (self));
+
+	if (g_strcmp0 (self->priv->position, position) == 0)
+		return;
+
+	local_position = self->priv->position;
+	self->priv->position = g_strdup (position);
+	g_free (local_position);
+	g_object_notify (G_OBJECT (self), "position");
+}
+
 /**
  * gdata_tasks_task_get_notes:
  * @self: a #GDataTasksTask
