@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * GData Client
- * Copyright (C) Philip Withnall 2009, 2010, 2014, 2015 <philip@tecnocode.co.uk>
+ * Copyright (C) Philip Withnall 2009, 2010, 2014, 2015, 2017 <philip@tecnocode.co.uk>
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -641,6 +641,100 @@ test_event_json (void)
 	"}");
 }
 
+static void
+test_event_json_attendees (void)
+{
+	GDataCalendarEvent *event;
+	GList/*<unowned GDataGDWho>*/ *l;
+	guint n_people;
+	const struct {
+		const gchar *relation_type;
+		const gchar *value_string;
+		const gchar *email_address;
+	} expected[] = {
+		{ GDATA_GD_WHO_EVENT_ATTENDEE, "Joe Hibbs", "person1@gmail.com" },
+		{ GDATA_GD_WHO_EVENT_ATTENDEE, "Me McMeeson", "me@gmail.com" },
+		{ GDATA_GD_WHO_EVENT_ATTENDEE, NULL, "person2@gmail.com" },
+		{ GDATA_GD_WHO_EVENT_ATTENDEE, "Example Person 3", "person3@gmail.com" },
+		{ GDATA_GD_WHO_EVENT_ATTENDEE, NULL, "person4@gmail.com" },
+		{ GDATA_GD_WHO_EVENT_ORGANIZER, "Ruth Pettut", "blah@example.com" },
+	};
+	GError *error = NULL;
+
+	event = GDATA_CALENDAR_EVENT (gdata_parsable_new_from_json (GDATA_TYPE_CALENDAR_EVENT, "{"
+		"'kind': 'calendar#event',"
+		"'id': 'some-id',"
+		"'created': '2017-02-04T17:53:47.000Z',"
+		"'summary': 'Duff this',"
+		"'organizer': {"
+			"'email': 'blah@example.com',"
+			"'displayName': 'Ruth Pettut'"
+		"},"
+		"'attendees': ["
+			"{"
+				"'email': 'person1@gmail.com',"
+				"'displayName': 'Joe Hibbs',"
+				"'responseStatus': 'accepted'"
+			"},"
+			"{"
+				"'email': 'me@gmail.com',"
+				"'displayName': 'Me McMeeson',"
+				"'self': true,"
+				"'responseStatus': 'needsAction'"
+			"},"
+			"{"
+				"'email': 'person2@gmail.com',"
+				"'responseStatus': 'needsAction'"
+			"},"
+			"{"
+				"'email': 'person3@gmail.com',"
+				"'displayName': 'Example Person 3',"
+				"'responseStatus': 'tentative',"
+				"'comment': 'Some poor excuse about not coming.'"
+			"},"
+			"{"
+				"'email': 'person4@gmail.com',"
+				"'responseStatus': 'accepted'"
+			"},"
+			"{"
+				"'email': 'blah@example.com',"
+				"'displayName': 'Ruth Pettut',"
+				"'organizer': true,"
+				"'responseStatus': 'accepted'"
+			"}"
+		"]"
+	"}", -1, &error));
+	g_assert_no_error (error);
+	g_assert (GDATA_IS_ENTRY (event));
+	g_clear_error (&error);
+
+	/* Check attendee details. */
+	for (n_people = 0, l = gdata_calendar_event_get_people (event);
+	     l != NULL;
+	     n_people += 1, l = l->next) {
+		GDataGDWho *who = GDATA_GD_WHO (l->data);
+		gsize i;
+
+		g_test_message ("Examining attendee: %s",
+		                gdata_gd_who_get_email_address (who));
+
+		for (i = 0; i < G_N_ELEMENTS (expected); i++) {
+			if (g_strcmp0 (gdata_gd_who_get_email_address (who),
+			               expected[i].email_address) == 0) {
+				g_assert_cmpstr (gdata_gd_who_get_relation_type (who), ==, expected[i].relation_type);
+				g_assert_cmpstr (gdata_gd_who_get_value_string (who), ==, expected[i].value_string);
+				break;
+			}
+		}
+
+		g_assert_cmpuint (i, <, G_N_ELEMENTS (expected));
+	}
+
+	g_assert_cmpuint (n_people, ==, G_N_ELEMENTS (expected));
+
+	g_object_unref (event);
+}
+
 static void
 test_event_json_dates (void)
 {
@@ -745,6 +839,37 @@ test_event_json_dates (void)
 	}
 }
 
+static void
+test_event_json_organizer (void)
+{
+	GDataCalendarEvent *event;
+	GError *error = NULL;
+
+	event = GDATA_CALENDAR_EVENT (gdata_parsable_new_from_json (GDATA_TYPE_CALENDAR_EVENT, "{"
+		"'kind': 'calendar#event',"
+		"'id': 'some-id',"
+		"'created': '2013-12-22T18:00:00.000Z',"
+		"'summary': 'FOSDEM GNOME Beer Event',"
+		"'organizer': {"
+			"'id': 'another-id',"
+			"'displayName': 'Guillaume Desmottes'"
+		"},"
+		"'attendees': ["
+			"{"
+				"'id': 'another-id',"
+				"'displayName': 'Guillaume Desmottes',"
+				"'organizer': true,"
+				"'responseStatus': 'accepted'"
+			"}"
+		"]"
+	"}", -1, &error));
+	g_assert_no_error (error);
+	g_assert (GDATA_IS_ENTRY (event));
+	g_clear_error (&error);
+
+	g_object_unref (event);
+}
+
 static void
 test_event_json_recurrence (void)
 {
@@ -978,12 +1103,14 @@ test_query_uri (void)
 	gchar *query_uri;
 	GDataCalendarQuery *query = gdata_calendar_query_new ("q");
 
-	gdata_calendar_query_set_future_events (query, TRUE);
-	g_assert (gdata_calendar_query_get_future_events (query) == TRUE);
+	/* Set to false or it will override our startMin below. */
+	gdata_calendar_query_set_future_events (query, FALSE);
+	g_assert (gdata_calendar_query_get_future_events (query) == FALSE);
 
 	gdata_calendar_query_set_order_by (query, "starttime");
 	g_assert_cmpstr (gdata_calendar_query_get_order_by (query), ==, "starttime");
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	g_time_val_from_iso8601 ("2009-04-17T15:00:00.000Z", &time_val);
 	gdata_calendar_query_set_recurrence_expansion_start (query, time_val.tv_sec);
 	_time = gdata_calendar_query_get_recurrence_expansion_start (query);
@@ -993,12 +1120,15 @@ test_query_uri (void)
 	gdata_calendar_query_set_recurrence_expansion_end (query, time_val.tv_sec);
 	_time = gdata_calendar_query_get_recurrence_expansion_end (query);
 	g_assert_cmpint (_time, ==, time_val.tv_sec);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 	gdata_calendar_query_set_single_events (query, TRUE);
 	g_assert (gdata_calendar_query_get_single_events (query) == TRUE);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	gdata_calendar_query_set_sort_order (query, "descending");
 	g_assert_cmpstr (gdata_calendar_query_get_sort_order (query), ==, "descending");
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 	g_time_val_from_iso8601 ("2009-04-17T15:00:00.000Z", &time_val);
 	gdata_calendar_query_set_start_min (query, time_val.tv_sec);
@@ -1021,26 +1151,23 @@ test_query_uri (void)
 
 	/* Check the built query URI with a normal feed URI */
 	query_uri = gdata_query_get_query_uri (GDATA_QUERY (query), "http://example.com");
-	g_assert_cmpstr (query_uri, ==, "http://example.com?q=q&futureevents=true&orderby=starttime&recurrence-expansion-start=2009-04-17T15:00:00Z"
-	                                "&recurrence-expansion-end=2010-04-17T15:00:00Z&singleevents=true&sortorder=descending"
-	                                "&start-min=2009-04-17T15:00:00Z&start-max=2010-04-17T15:00:00Z&ctz=America%2FLos_Angeles&max-attendees=15"
-	                                "&showdeleted=true");
+	g_assert_cmpstr (query_uri, ==, "http://example.com?q=q&orderBy=startTime&singleEvents=true"
+			                "&timeMin=2009-04-17T15:00:00Z&timeMax=2010-04-17T15:00:00Z&timeZone=America%2FLos_Angeles&maxAttendees=15"
+			                "&showDeleted=true");
 	g_free (query_uri);
 
 	/* …with a feed URI with a trailing slash */
 	query_uri = gdata_query_get_query_uri (GDATA_QUERY (query), "http://example.com/");
-	g_assert_cmpstr (query_uri, ==, "http://example.com/?q=q&futureevents=true&orderby=starttime&recurrence-expansion-start=2009-04-17T15:00:00Z"
-	                                "&recurrence-expansion-end=2010-04-17T15:00:00Z&singleevents=true&sortorder=descending"
-	                                "&start-min=2009-04-17T15:00:00Z&start-max=2010-04-17T15:00:00Z&ctz=America%2FLos_Angeles&max-attendees=15"
-	                                "&showdeleted=true");
+	g_assert_cmpstr (query_uri, ==, "http://example.com/?q=q&orderBy=startTime&singleEvents=true"
+	                                "&timeMin=2009-04-17T15:00:00Z&timeMax=2010-04-17T15:00:00Z&timeZone=America%2FLos_Angeles&maxAttendees=15"
+	                                "&showDeleted=true");
 	g_free (query_uri);
 
 	/* …with a feed URI with pre-existing arguments */
 	query_uri = gdata_query_get_query_uri (GDATA_QUERY (query), "http://example.com/bar/?test=test&this=that");
-	g_assert_cmpstr (query_uri, ==, "http://example.com/bar/?test=test&this=that&q=q&futureevents=true&orderby=starttime"
-	                                "&recurrence-expansion-start=2009-04-17T15:00:00Z&recurrence-expansion-end=2010-04-17T15:00:00Z"
-	                                "&singleevents=true&sortorder=descending&start-min=2009-04-17T15:00:00Z&start-max=2010-04-17T15:00:00Z"
-	                                "&ctz=America%2FLos_Angeles&max-attendees=15&showdeleted=true");
+	g_assert_cmpstr (query_uri, ==, "http://example.com/bar/?test=test&this=that&q=q&orderBy=startTime"
+	                                "&singleEvents=true&timeMin=2009-04-17T15:00:00Z&timeMax=2010-04-17T15:00:00Z"
+	                                "&timeZone=America%2FLos_Angeles&maxAttendees=15&showDeleted=true");
 	g_free (query_uri);
 
 	g_object_unref (query);
@@ -1061,10 +1188,14 @@ test_query_etag (void)
 
 	CHECK_ETAG (gdata_calendar_query_set_future_events (query, FALSE))
 	CHECK_ETAG (gdata_calendar_query_set_order_by (query, "shizzle"))
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	CHECK_ETAG (gdata_calendar_query_set_recurrence_expansion_start (query, -1))
 	CHECK_ETAG (gdata_calendar_query_set_recurrence_expansion_end (query, -1))
+G_GNUC_END_IGNORE_DEPRECATIONS
 	CHECK_ETAG (gdata_calendar_query_set_single_events (query, FALSE))
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	CHECK_ETAG (gdata_calendar_query_set_sort_order (query, "shizzle"))
+G_GNUC_END_IGNORE_DEPRECATIONS
 	CHECK_ETAG (gdata_calendar_query_set_start_min (query, -1))
 	CHECK_ETAG (gdata_calendar_query_set_start_max (query, -1))
 	CHECK_ETAG (gdata_calendar_query_set_timezone (query, "about now"))
@@ -1439,7 +1570,9 @@ main (int argc, char *argv[])
 	            tear_down_temp_calendar_acls);
 
 	g_test_add_func ("/calendar/event/json", test_event_json);
+	g_test_add_func ("/calendar/event/json/attendees", test_event_json_attendees);
 	g_test_add_func ("/calendar/event/json/dates", test_event_json_dates);
+	g_test_add_func ("/calendar/event/json/organizer", test_event_json_organizer);
 	g_test_add_func ("/calendar/event/json/recurrence", test_event_json_recurrence);
 	g_test_add_func ("/calendar/event/escaping", test_event_escaping);
 	g_test_add_func ("/calendar/event/parser/minimal",
