@@ -125,11 +125,11 @@ test_query_uri (void)
 	                 "?updated-min=1970-01-01T01:53:09Z"
 	                 "&max-results=10"
 	                 "&maxResults=10"
-	                 "&updatedMin=1970-01-01T01:53:09.000001+00:00"
-	                 "&completedMin=1970-01-01T01:34:38.000001+00:00"
-	                 "&completedMax=1970-01-01T00:20:34.000001+00:00"
-	                 "&dueMin=1970-01-01T00:39:05.000001+00:00"
-	                 "&dueMax=1970-01-01T00:57:36.000001+00:00"
+	                 "&updatedMin=1970-01-01T01:53:09Z"
+	                 "&completedMin=1970-01-01T01:34:38Z"
+	                 "&completedMax=1970-01-01T00:20:34Z"
+	                 "&dueMin=1970-01-01T00:39:05Z"
+	                 "&dueMax=1970-01-01T00:57:36Z"
 	                 "&showCompleted=true"
 	                 "&showDeleted=true"
 	                 "&showHidden=true");
@@ -153,11 +153,11 @@ test_query_uri (void)
 	                 "?updated-min=1970-01-01T01:53:09Z"
 	                 "&max-results=10"
 	                 "&maxResults=10"
-	                 "&updatedMin=1970-01-01T01:53:09.000001+00:00"
-	                 "&completedMin=1970-01-01T01:34:38.000001+00:00"
-	                 "&completedMax=1970-01-01T00:20:34.000001+00:00"
-	                 "&dueMin=1970-01-01T00:39:05.000001+00:00"
-	                 "&dueMax=1970-01-01T00:57:36.000001+00:00"
+	                 "&updatedMin=1970-01-01T01:53:09Z"
+	                 "&completedMin=1970-01-01T01:34:38Z"
+	                 "&completedMax=1970-01-01T00:20:34Z"
+	                 "&dueMin=1970-01-01T00:39:05Z"
+	                 "&dueMax=1970-01-01T00:57:36Z"
 	                 "&showCompleted=false"
 	                 "&showDeleted=false"
 	                 "&showHidden=false");
@@ -256,6 +256,8 @@ test_task_properties (void)
 	gdata_tasks_task_set_due (task, 1409419209);
 	gdata_tasks_task_set_completed (task, 1409419200);  /* 9 seconds to spare! */
 	gdata_tasks_task_set_is_deleted (task, FALSE);
+	gdata_tasks_task_set_position (task, "0");
+	gdata_tasks_task_set_parent (task, NULL);
 
 	/* Check the properties of the object */
 	g_object_get (G_OBJECT (task),
@@ -278,7 +280,7 @@ test_task_properties (void)
 	g_assert_cmpstr (title, ==, "some-title");
 	g_assert_cmpint (updated, ==, -1);
 	g_assert_cmpstr (parent, ==, NULL);
-	g_assert_cmpstr (position, ==, NULL);
+	g_assert_cmpstr (position, ==, "0");
 	g_assert_cmpstr (notes, ==, "some-notes");
 	g_assert_cmpstr (status, ==, GDATA_TASKS_STATUS_NEEDS_ACTION);
 	g_assert_cmpint (due, ==, 1409419209);
@@ -302,11 +304,13 @@ test_task_properties (void)
 	              "due", (gint64) 1409419200,
 	              "completed", (gint64) 1409419200,  /* no time to spare! */
 	              "is-deleted", TRUE,
+		      "parent", "parent-uid",
+		      "position", "1",
 	              NULL);
 
 	/* Check the properties using the getters. */
-	g_assert_cmpstr (gdata_tasks_task_get_parent (task), ==, NULL);
-	g_assert_cmpstr (gdata_tasks_task_get_position (task), ==, NULL);
+	g_assert_cmpstr (gdata_tasks_task_get_parent (task), ==, "parent-uid");
+	g_assert_cmpstr (gdata_tasks_task_get_position (task), ==, "1");
 	g_assert_cmpstr (gdata_tasks_task_get_notes (task), ==, "more-notes");
 	g_assert_cmpstr (gdata_tasks_task_get_status (task), ==,
 	                 GDATA_TASKS_STATUS_COMPLETED);
@@ -322,9 +326,11 @@ test_task_properties (void)
 			"\"title\": \"some-other-title\","
 			"\"notes\": \"more-notes\","
 			"\"status\": \"completed\","
-			"\"due\": \"2014-08-30T17:20:00.000001+00:00\","
-			"\"completed\": \"2014-08-30T17:20:00.000001+00:00\","
+			"\"due\": \"2014-08-30T17:20:00Z\","
+			"\"completed\": \"2014-08-30T17:20:00Z\","
 			"\"deleted\": true,"
+			"\"position\": \"1\","
+			"\"parent\": \"parent-uid\","
 			"\"hidden\": false"
 		"}");
 
@@ -337,9 +343,11 @@ test_task_properties (void)
 			"\"title\": \"some-other-title\","
 			"\"notes\": \"more-notes\","
 			"\"status\": \"completed\","
-			"\"due\": \"2014-08-30T17:20:00.000001+00:00\","
-			"\"completed\": \"2014-08-30T17:20:00.000001+00:00\","
+			"\"due\": \"2014-08-30T17:20:00Z\","
+			"\"completed\": \"2014-08-30T17:20:00Z\","
 			"\"deleted\": false,"
+			"\"position\": \"1\","
+			"\"parent\": \"parent-uid\","
 			"\"hidden\": false"
 		"}");
 
@@ -501,14 +509,14 @@ test_task_parser_normal (void)
 			"\"id\": \"some-id\","
 			"\"etag\": \"some-etag\","
 			"\"title\": \"some-title \\\"with quotes\\\"\","
-			"\"updated\": \"2014-08-30T19:40:00.000001+00:00\","
+			"\"updated\": \"2014-08-30T19:40:00Z\","
 			"\"selfLink\": \"http://some-uri/\","
 			"\"parent\": \"some-parent-id\","
 			"\"position\": \"some-position\","
 			"\"notes\": \"Some notes!\","
 			"\"status\": \"needsAction\","
-			"\"due\": \"2014-08-30T20:00:00.000001+00:00\","
-			"\"completed\": \"2014-08-30T20:10:05.000001+00:00\","
+			"\"due\": \"2014-08-30T20:00:00Z\","
+			"\"completed\": \"2014-08-30T20:10:05Z\","
 			"\"deleted\": false,"
 			"\"hidden\": true,"
 			/* Unhandled for the moment: */
